@@ -25,17 +25,16 @@
 
 #include <glib.h>
 
-GList *   get_wildcard_file_list    (gchar *directory, 
-				     const gchar *filter_pattern, 
-				     gboolean recursive,
-				     gboolean follow_links,
-				     gboolean same_fs,
-				     gboolean no_backup_files,
-				     gboolean no_dot_files,
-				     gboolean ignorecase);
+GList *   get_wildcard_file_list    (const char *directory, 
+				     const char *filter_pattern, 
+				     gboolean    recursive,
+				     gboolean    follow_links,
+				     gboolean    same_fs,
+				     gboolean    no_backup_files,
+				     gboolean    no_dot_files,
+				     gboolean    ignorecase);
 
-
-GList *   get_directory_file_list   (const gchar *directory,
-				     const gchar *base_dir); 
+GList *   get_directory_file_list   (const char *directory,
+				     const char *base_dir); 
 
 #endif /* _FILE_LIST_H */
