@@ -26,10 +26,37 @@
 
 #include <glib.h>
 #include "preferences.h"
+#include "fr-process.h"
+#include "window.h"
 
-extern GList *window_list;
-extern GList *viewer_list;
-extern Preferences preferences;
+
+typedef struct {
+	FRWindow  *window;
+	FRProcess *process;
+	char      *filename;
+	char      *e_filename;
+	char      *temp_dir;
+} ViewerData;
+
+typedef struct {
+	FRWindow  *window;
+	FRProcess *process;
+	char      *command;
+	GList     *file_list;
+	char      *temp_dir;
+} CommandData;
+
+
+void  viewer_done      (ViewerData  *vdata);
+void  command_done     (CommandData *cdata);
+void  install_scripts  ();
+void  remove_scripts   ();
+
+
+extern GList       *window_list;
+extern GList       *viewer_list;
+extern GList       *command_list;
+extern gint         force_directory_creation;
 
 
 #endif /* MAIN_H */
