@@ -22,22 +22,26 @@
 
 
 #include <config.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <gnome.h>
 #include "main.h"
+#include "gtk-utils.h"
 #include "window.h"
 #include "file-utils.h"
 #include "fr-process.h"
+#include "gconf-utils.h"
 #include "menu-callbacks.h"
 
 
 void
 new_window_cb (GtkWidget *widget, 
-	       void *data)
+	       void      *data)
 {
 	FRWindow *window;
+
 	window = window_new ();
 	gtk_widget_show (window->app);
 }
@@ -45,10 +49,9 @@ new_window_cb (GtkWidget *widget,
 
 void
 close_window_cb (GtkWidget *widget, 
-		 void *data)
+		 void      *data)
 {
-	FRWindow *window = data;
-	window_close (window);
+	window_close ((FRWindow *) data);
 }
 
 
@@ -64,8 +67,8 @@ new_file_destroy_cb (GtkWidget *w,
 
 static void
 new_archive (GtkWidget *file_sel, 
-	     FRWindow *window, 
-	     gchar *path)
+	     FRWindow  *window, 
+	     gchar     *path)
 {
 	window_archive_new (window, path);	
 	gtk_widget_destroy (file_sel);
@@ -76,8 +79,8 @@ static guint
 opt_menu_get_active_idx (GtkWidget *opt_menu)
 {
         GtkWidget *item;
-        guint idx;
-        GList *scan;
+        guint      idx;
+        GList     *scan;
         GtkWidget *menu;
 
         menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (opt_menu));
@@ -95,8 +98,8 @@ opt_menu_get_active_idx (GtkWidget *opt_menu)
 
 
 typedef struct {
-	char * name;
-	char * ext;
+	char *name;
+	char *ext;
 } FileTypeDescription;
 
 
@@ -122,12 +125,12 @@ static int type_desc_n = sizeof (type_desc) / sizeof (FileTypeDescription);
 static char *
 get_full_path (GtkWidget *file_sel)
 {
-	GtkWidget *opt_menu;
-	gchar *full_path;
-	gchar *path;
-	int file_type_idx;
+	GtkWidget   *opt_menu;
+	char        *full_path;
+	const char  *path;
+	int          file_type_idx;
 
-	opt_menu = gtk_object_get_data (GTK_OBJECT (file_sel), "fr_opt_menu");
+	opt_menu = g_object_get_data (G_OBJECT (file_sel), "fr_opt_menu");
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_sel));
 
 	file_type_idx = opt_menu_get_active_idx (opt_menu);
@@ -142,39 +145,15 @@ get_full_path (GtkWidget *file_sel)
 }
 
 
-static void
-new_file_overwrite_cb (gint reply, gpointer data)
-{
-	GtkWidget *file_sel = data;
-	FRWindow *window;
-	gchar *path;
-
-	window = gtk_object_get_data (GTK_OBJECT (file_sel), "fr_window");
-	
-	if (reply != GNOME_YES) 
-		return;
-
-	path = get_full_path (file_sel);
-        if (path == NULL) {
-		gtk_widget_destroy (file_sel);
-                return;
-	}
-
-	unlink (path);
-	new_archive (file_sel, window, path);
-	g_free (path);
-}
-
-
 static void 
 new_file_ok_cb (GtkWidget *w,
 		GtkWidget *file_sel)
 {
 	FRWindow *window;
-	gchar *path;
-	gchar *dir;
+	gchar    *path;
+	gchar    *dir;
 
-	window = gtk_object_get_data (GTK_OBJECT (file_sel), "fr_window");
+	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 
 	path = get_full_path (file_sel);
         if (path == NULL) {
@@ -189,9 +168,13 @@ new_file_ok_cb (GtkWidget *w,
 		g_free (dir);
 		g_free (path);
 
-		dialog = gnome_error_dialog_parented (_("You don't have permission to create an archive in this directory"), GTK_WINDOW (window->app));
-		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
-
+		dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 _("You don't have permission to create an archive in this folder"));
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
 		return;
 	}
 	g_free (dir);
@@ -202,14 +185,39 @@ new_file_ok_cb (GtkWidget *w,
 
 	if (path_is_file (path)) {
 		GtkWidget *dialog;
+		int r;
 
-		g_free (path);
-		dialog = gnome_question_dialog_parented (_("Archive already exists.  Do you want to overwrite it ?"), new_file_overwrite_cb, file_sel, GTK_WINDOW (window->app));
-		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
-	} else {
-		new_archive (file_sel, window, path);
-		g_free (path);
-	}
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_MODAL,
+						  GTK_STOCK_DIALOG_QUESTION,
+						  _("Archive already exists.  Do you want to overwrite it ?"),
+						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						  _("Overwrite"), GTK_RESPONSE_YES,
+						  NULL);
+
+		r = gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+
+		if (r != GTK_RESPONSE_YES) {
+			g_free (path);
+			return;
+		}
+
+		if (unlink (path) != 0) {
+			GtkWidget *dialog;
+			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
+							 GTK_DIALOG_DESTROY_WITH_PARENT,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_CLOSE,
+							 _("Could not delete old archive."));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (GTK_WIDGET (dialog));
+			return;
+		}
+	} 
+
+	new_archive (file_sel, window, path);
+	g_free (path);
 }
 
 
@@ -218,13 +226,13 @@ build_file_type_menu (FRWindow *window)
 {
         GtkWidget *menu;
         GtkWidget *item;
-	int i;
+	int        i;
 
         menu = gtk_menu_new ();
         for (i = 0; i < type_desc_n; i++) {
                 item = gtk_menu_item_new_with_label (_(type_desc[i].name));
 		gtk_widget_show (item);
-                gtk_menu_append (GTK_MENU (menu), item);
+                gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
         }
 
 	return menu;
@@ -233,15 +241,15 @@ build_file_type_menu (FRWindow *window)
 
 void
 new_archive_cb (GtkWidget *widget, 
-		void *data)
+		void      *data)
 {
-	FRWindow *window = data;
+	FRWindow  *window = data;
 	GtkWidget *file_sel;
 	GtkWidget *frame;
 	GtkWidget *vbox;
 	GtkWidget *opt_menu;
 	GtkWidget *menu;
-	char *dir;
+	char      *dir;
 
 	file_sel = gtk_file_selection_new (_("New Archive"));
 
@@ -267,23 +275,23 @@ new_archive_cb (GtkWidget *widget,
 
 	/**/
 
-	gtk_object_set_data (GTK_OBJECT (file_sel), "fr_window", window);
-	gtk_object_set_data (GTK_OBJECT (file_sel), "fr_opt_menu", opt_menu);
+	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
+	g_object_set_data (G_OBJECT (file_sel), "fr_opt_menu", opt_menu);
 	
-	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
-                            "clicked", 
-                            (GtkSignalFunc) new_file_ok_cb, 
-                            file_sel);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
+			  "clicked", 
+			  G_CALLBACK (new_file_ok_cb), 
+			  file_sel);
 
-        gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
-                            "clicked", 
-                            (GtkSignalFunc) gtk_widget_destroy,
-                            GTK_OBJECT (file_sel));
+	g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
+				  "clicked", 
+				  G_CALLBACK (gtk_widget_destroy),
+				  G_OBJECT (file_sel));
 
-        gtk_signal_connect (GTK_OBJECT (file_sel),
-                            "destroy", 
-                            (GtkSignalFunc) new_file_destroy_cb,
-                            file_sel);
+	g_signal_connect (G_OBJECT (file_sel),
+			  "destroy", 
+			  G_CALLBACK (new_file_destroy_cb),
+			  file_sel);
 
 	gtk_window_set_modal (GTK_WINDOW (file_sel),TRUE);
 	gtk_widget_show_all (file_sel);
@@ -305,9 +313,9 @@ open_file_ok_cb (GtkWidget *w,
                  GtkWidget *file_sel)
 {
 	FRWindow *window;
-	gchar *path;
+	const gchar *path;
 
-	window = gtk_object_get_data (GTK_OBJECT (file_sel), "fr_window");
+	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_sel));
 
         if (path == NULL)
@@ -321,7 +329,7 @@ open_file_ok_cb (GtkWidget *w,
 
 void
 open_archive_cb (GtkWidget *widget, 
-		 void *data)
+		 void      *data)
 {
 	GtkWidget *file_sel;
 	FRWindow *window = data;
@@ -333,22 +341,22 @@ open_archive_cb (GtkWidget *widget,
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
 	g_free (dir);
 
-	gtk_object_set_data (GTK_OBJECT (file_sel), "fr_window", window);
+	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
 	
-	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
-                            "clicked", 
-                            (GtkSignalFunc) open_file_ok_cb, 
-                            file_sel);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
+			  "clicked", 
+			  G_CALLBACK (open_file_ok_cb), 
+			  file_sel);
+ 
+	g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
+				  "clicked", 
+				  G_CALLBACK (gtk_widget_destroy),
+				  G_OBJECT (file_sel));
 
-        gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
-                            "clicked", 
-                            (GtkSignalFunc) gtk_widget_destroy,
-                            GTK_OBJECT (file_sel));
-
-        gtk_signal_connect (GTK_OBJECT (file_sel),
-                            "destroy", 
-                            (GtkSignalFunc) open_file_destroy_cb,
-                            file_sel);
+	g_signal_connect (G_OBJECT (file_sel),
+			  "destroy", 
+			  G_CALLBACK (open_file_destroy_cb),
+			  file_sel);
 
 	gtk_window_set_modal (GTK_WINDOW (file_sel),TRUE);
 	gtk_widget_show (file_sel);
@@ -357,10 +365,9 @@ open_archive_cb (GtkWidget *widget,
 
 void
 close_archive_cb (GtkWidget *widget, 
-		  void *data)
+		  void      *data)
 {
-	FRWindow *window = data;
-	window_archive_close (window);
+	window_archive_close ((FRWindow*) data);
 }
 
 
@@ -368,14 +375,14 @@ close_archive_cb (GtkWidget *widget,
 
 
 typedef struct {
-	FRWindow *window;
-	gboolean copy;
+	FRWindow  *window;
+	gboolean   copy;
 	GtkWidget *file_sel;
 } CopyMoveData;
 
 
 static void
-file_sel_destroy_cb (GtkWidget *w,
+file_sel_destroy_cb (GtkWidget    *w,
 		     CopyMoveData *data)
 {
 	g_free (data);
@@ -383,31 +390,63 @@ file_sel_destroy_cb (GtkWidget *w,
 
 
 static void 
-copy_archive_ok_cb (GtkWidget *w,
+copy_archive_ok_cb (GtkWidget    *w,
 		    CopyMoveData *data)
 {
-	FRWindow *window;
-	char *path, *new_filename;
+	FRWindow   *window;
+	const char *path;
+	char       *new_filename;
+
+	gtk_widget_hide (data->file_sel);
 
 	window = data->window;
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (data->file_sel));
 
-	if (path == NULL)
+	if (path == NULL) {
+                gtk_widget_destroy (data->file_sel);
 		return;
+	}
 
 	if (path[strlen (path) - 1] == '/')
 		new_filename = g_strconcat (path, file_name_from_path (window->archive_filename), NULL);
 	else
 		new_filename = g_strconcat (path, "/", file_name_from_path (window->archive_filename), NULL);
 
+	if (path_is_file (new_filename)) {
+		GtkWidget *d;
+		int        r;
+
+		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					     GTK_DIALOG_MODAL,
+					     GTK_STOCK_DIALOG_QUESTION,
+					     _("Archive already exists.  Do you want to overwrite it ?"),
+					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					     _("Overwrite"), GTK_RESPONSE_YES,
+					     NULL);
+	
+		r = gtk_dialog_run (GTK_DIALOG (d));
+		gtk_widget_destroy (GTK_WIDGET (d));
+		
+		if (r != GTK_RESPONSE_YES) {
+			g_free (new_filename);
+			gtk_widget_destroy (data->file_sel);
+			return;
+		}
+	}
+	
 	if (data->copy) {
 #ifdef DEBUG
 		g_print ("cp %s %s\n", window->archive_filename, new_filename);
 #endif
 		if (! file_copy (window->archive_filename, new_filename)) {
 			GtkWidget *dialog;
-			dialog = gnome_error_dialog_parented (_("Could not copy archive"), GTK_WINDOW (window->app));
-			gtk_widget_show (dialog);
+			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
+							 GTK_DIALOG_DESTROY_WITH_PARENT,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_CLOSE,
+							 _("Could not copy archive"));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
 		}
 	} else {
 #ifdef DEBUG
@@ -417,8 +456,13 @@ copy_archive_ok_cb (GtkWidget *w,
 			window_archive_rename (window, new_filename);
 		else {
 			GtkWidget *dialog;
-			dialog = gnome_error_dialog_parented (_("Could not move archive"), GTK_WINDOW (window->app));
-			gtk_widget_show (dialog);
+			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
+							 GTK_DIALOG_DESTROY_WITH_PARENT,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_CLOSE,
+							 _("Could not move archive"));
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
 		}
 	}
 
@@ -428,10 +472,11 @@ copy_archive_ok_cb (GtkWidget *w,
 
 
 static void
-copy_or_move_archive (FRWindow *window, gboolean copy)
+copy_or_move_archive (FRWindow *window, 
+		      gboolean  copy)
 {
-	GtkWidget *file_sel;
-	char *dir;
+	GtkWidget    *file_sel;
+	char         *dir;
 	CopyMoveData *data;
 
 	data = g_new (CopyMoveData, 1);
@@ -442,139 +487,179 @@ copy_or_move_archive (FRWindow *window, gboolean copy)
 	dir = g_strconcat (window->open_default_dir, "/", NULL);
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
 	g_free (dir);
+
 	gtk_widget_set_sensitive (GTK_FILE_SELECTION (file_sel)->file_list,
 				  FALSE);
 
-	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
-                            "clicked", 
-			    (GtkSignalFunc) copy_archive_ok_cb, 
-			    data);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
+			  "clicked", 
+			  G_CALLBACK (copy_archive_ok_cb), 
+			  data);
 
-        gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
-                            "clicked", 
-                            (GtkSignalFunc) gtk_widget_destroy,
-                            GTK_OBJECT (file_sel));
+	g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
+				  "clicked", 
+				  G_CALLBACK (gtk_widget_destroy),
+				  G_OBJECT (file_sel));
 
-        gtk_signal_connect (GTK_OBJECT (file_sel),
-                            "destroy", 
-                            (GtkSignalFunc) file_sel_destroy_cb,
-                            data);
+	g_signal_connect (G_OBJECT (file_sel),
+			  "destroy", 
+			  G_CALLBACK (file_sel_destroy_cb),
+			  data);
 
-	gtk_window_set_modal (GTK_WINDOW (file_sel),TRUE);
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	gtk_widget_show (file_sel);
 }
 
 
 void
 move_archive_cb (GtkWidget *widget, 
-		 void *data)
+		 void      *data)
 {
-	FRWindow *window = data;
-	copy_or_move_archive (window, FALSE);
+	copy_or_move_archive ((FRWindow *) data, FALSE);
 }
 
 
 void
 copy_archive_cb (GtkWidget *widget, 
-		 void *data)
+		 void      *data)
 {
-	FRWindow *window = data;
-	copy_or_move_archive (window, TRUE);
+	copy_or_move_archive ((FRWindow *) data, TRUE);
 }
 
 
 /* -- rename archive -- */
 
-static void
-rename_string_cb (gchar * string, gpointer data)
-{
-	FRWindow *window = data;
-	char *dir, *filename, *new_filename;
 
-	if (string == NULL)
+static char*
+remove_extension (const char *filename)
+{
+	const char *ext;
+
+	ext = fr_archive_utils__get_file_name_ext (filename);
+	if (ext == NULL)
+		return g_strdup (filename);
+	else
+		return g_strndup (filename, strlen (filename) - strlen (ext));
+}
+
+
+void
+rename_archive_cb (GtkWidget *widget, 
+		   void      *data)
+{	
+	FRWindow   *window = data;
+	char       *name;
+	char       *utf8_old_string;
+	char       *utf8_string;
+	char       *string;
+	char       *dir, *filename, *new_filename;
+
+	name = remove_extension (file_name_from_path (window->archive_filename));
+	utf8_old_string = g_locale_to_utf8 (name, -1, NULL, NULL, NULL);
+	g_free (name);
+	utf8_string = _gtk_request_dialog_run (GTK_WINDOW (window->app),
+					       (GTK_DIALOG_DESTROY_WITH_PARENT 
+						| GTK_DIALOG_MODAL),
+					       _("New archive name (without extension)"),
+					       utf8_old_string,
+					       1024,
+					       GTK_STOCK_CANCEL,
+					       _("_Rename"));
+	g_free (utf8_old_string);
+	if (utf8_string == NULL)
 		return;
 
+	string = g_locale_from_utf8 (utf8_string, -1, NULL, NULL, NULL);
+	g_free (utf8_string);
+
 	filename = window->archive->filename;
 	dir = remove_level_from_path (filename);
 	new_filename = g_strconcat (dir, 
 				    "/", 
 				    file_name_from_path (string),
-				    fr_archive_utils_get_file_name_ext (window->archive->filename),
+				    fr_archive_utils__get_file_name_ext (window->archive->filename),
 				    NULL);
+	g_free (dir);
+	g_free (string);
+
+	if (path_is_file (new_filename)) {
+		GtkWidget *d;
+		int        r;
+
+		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					     GTK_DIALOG_MODAL,
+					     GTK_STOCK_DIALOG_QUESTION,
+					     _("Archive already exists.  Do you want to overwrite it ?"),
+					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					     _("Overwrite"), GTK_RESPONSE_YES,
+					     NULL);
+	
+		r = gtk_dialog_run (GTK_DIALOG (d));
+		gtk_widget_destroy (GTK_WIDGET (d));
+		
+		if (r != GTK_RESPONSE_YES) {
+			g_free (new_filename);
+			return;
+		}
+	}
 
 #ifdef DEBUG
 	g_print ("rename %s --> %s\n", filename, new_filename);
 #endif
 
-	if (rename (filename, new_filename) == 0) {
+	if (rename (filename, new_filename) == 0) 
 		window_archive_rename (window, new_filename);
-	}
 
 	g_free (new_filename);
-	g_free (dir);
-	g_free (string);
-}
-
-
-void
-rename_archive_cb (GtkWidget *widget, 
-		   void *data)
-{	
-	FRWindow *window = data;
-	GtkWidget *dialog;
-
-	dialog = gnome_request_dialog (FALSE, _("New archive name (without extension)"), "", 1024, rename_string_cb, window, GTK_WINDOW (window->app));
-	gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
 }
 
 
 /* -- delete archive -- */
 
 
-static void
-delete_reply_cb (gint reply, gpointer data)
-{
-	FRWindow *window = data;
-
-	if (reply != 0) 
-		return;
-
-#ifdef DEBUG
-	g_print ("rm %s\n", window->archive->filename);
-#endif
-
-	if (unlink (window->archive->filename) == 0)
-		window_archive_close (window);
-}
-
-
 void
 delete_archive_cb (GtkWidget *widget, 
 		   void *data)
 {
 	FRWindow *window = data;
 	GtkWidget *dialog;
+	int r;
 
-	dialog = gnome_question_dialog_modal_parented (_("Archive will be deleted, are you sure ?"), delete_reply_cb, window, GTK_WINDOW (window->app));
-	gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+	dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					  GTK_DIALOG_MODAL,
+					  GTK_STOCK_DIALOG_QUESTION,
+					  _("Archive will be deleted, are you sure ?"),
+					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					  GTK_STOCK_DELETE, GTK_RESPONSE_YES,
+					  NULL);
+
+	r = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+	if (r == GTK_RESPONSE_YES) {
+#ifdef DEBUG
+		g_print ("rm %s\n", window->archive->filename);
+#endif
+		if (unlink (window->archive->filename) == 0)
+			window_archive_close (window);
+	}
 }
 
 
 void
 quit_cb (GtkWidget *widget, 
-	 void *data)
+	 void      *data)
 {
-	window_close ((FRWindow*) data);
-	gtk_main_quit ();
+	while (window_list)
+                window_close ((FRWindow*) window_list->data);
 }
 
 
 void
 view_cb (GtkWidget *widget, 
-	 void *data)
+	 void      *data)
 {
 	FRWindow *window = data;
-	GList *file_list;
+	GList    *file_list;
 
 	file_list = window_get_file_list_selection (window, FALSE, NULL);
 	if (file_list == NULL) 
@@ -614,10 +699,8 @@ set_list_mode_flat_cb (GtkWidget *widget,
 		       void *data)
 {
 	GtkCheckMenuItem *mitem = GTK_CHECK_MENU_ITEM (widget);
-        
         if (! mitem->active)
                 return;
-
 	window_set_list_mode ((FRWindow*) data, WINDOW_LIST_MODE_FLAT);
 }
 
@@ -627,10 +710,8 @@ set_list_mode_as_dir_cb (GtkWidget *widget,
 			 void *data)
 {
 	GtkCheckMenuItem *mitem = GTK_CHECK_MENU_ITEM (widget);
-        
         if (! mitem->active)
                 return;
-
 	window_set_list_mode ((FRWindow*) data, WINDOW_LIST_MODE_AS_DIR);
 }
 
@@ -640,7 +721,48 @@ select_all_cb (GtkWidget *widget,
 	       void *data)
 {
 	FRWindow *window = data;
-	gtk_clist_select_all (GTK_CLIST (window->clist));
+	gtk_tree_selection_select_all (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)));
+}
+
+
+void
+deselect_all_cb (GtkWidget *widget, 
+		 void *data)
+{
+	FRWindow *window = data;
+	gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)));
+}
+
+
+void
+manual_cb (GtkWidget *widget, 
+           void      *data)
+{
+	FRWindow *window = data;
+	GError   *err;
+	
+        err = NULL;  
+        gnome_help_display ("file-roller", NULL, &err);
+        
+        if (err != NULL) {
+                GtkWidget *dialog;
+                
+                dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
+                                                 GTK_DIALOG_DESTROY_WITH_PARENT,                                                 GTK_MESSAGE_ERROR,
+                                                 GTK_BUTTONS_CLOSE,
+                                                 _("Could not display help: %s"),
+                                                 err->message);
+                
+                g_signal_connect (G_OBJECT (dialog), "response",
+                                  G_CALLBACK (gtk_widget_destroy),
+                                  NULL);
+                
+                gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+                
+                gtk_widget_show (dialog);
+                
+                g_error_free (err);
+        }
 }
 
 
@@ -648,17 +770,42 @@ void
 about_cb (GtkWidget *widget, 
 	  void *data)
 {
-	GtkWidget   *about;
-	const gchar *authors[] = {
-		"Paolo Bacchilega",
-		NULL
+	FRWindow         *window = data;
+	static GtkWidget *about = NULL;
+	GdkPixbuf        *logo;
+	const char       *authors[] = {
+		"Paolo Bacchilega <paolo.bacch@tin.it>", NULL
 	};
+	const char       *documenters [] = {
+		"Alexander Kirillov", NULL
+	};
+	const char       *translator_credits = _("translator_credits");
 
-	about = gnome_about_new ("File Roller", VERSION,
+	if (about != NULL) {
+		gtk_window_present (GTK_WINDOW (about));
+		return;
+	}
+
+	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/file-roller.png", NULL);
+	about = gnome_about_new ("File Roller", 
+				 VERSION,
 				 "Copyright (C) 2001 The Free Software Foundation, Inc.",
-				 authors,
 				 _("An archive manager for GNOME."),
-				 NULL);
+				 authors,
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 logo);
+	if (logo != NULL)
+                g_object_unref (logo);
+
+	gtk_window_set_destroy_with_parent (GTK_WINDOW (about), TRUE);
+	gtk_window_set_transient_for (GTK_WINDOW (about), 
+				      GTK_WINDOW (window->app));
+
+	g_signal_connect (G_OBJECT (about), 
+			  "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), 
+			  &about);
 
 	gtk_widget_show_all (about);
 }
@@ -675,7 +822,7 @@ sort_list_by_name (GtkWidget *widget,
 
 	window->sort_method = WINDOW_SORT_BY_NAME;
 	window->sort_type = GTK_SORT_ASCENDING;
-	window_update_file_list (window);
+	window_update_list_order (window);
 }
 
 
@@ -690,7 +837,7 @@ sort_list_by_type (GtkWidget *widget,
 
 	window->sort_method = WINDOW_SORT_BY_TYPE;
 	window->sort_type = GTK_SORT_ASCENDING;
-	window_update_file_list (window);
+	window_update_list_order (window);
 }
 
 
@@ -705,7 +852,7 @@ sort_list_by_size (GtkWidget *widget,
 
 	window->sort_method = WINDOW_SORT_BY_SIZE;
 	window->sort_type = GTK_SORT_ASCENDING;
-	window_update_file_list (window);
+	window_update_list_order (window);
 }
 
 
@@ -720,7 +867,7 @@ sort_list_by_time (GtkWidget *widget,
 
 	window->sort_method = WINDOW_SORT_BY_TIME;
 	window->sort_type = GTK_SORT_ASCENDING;
-	window_update_file_list (window);
+	window_update_list_order (window);
 }
 
 
@@ -735,7 +882,7 @@ sort_list_by_path (GtkWidget *widget,
 
 	window->sort_method = WINDOW_SORT_BY_PATH;
 	window->sort_type = GTK_SORT_ASCENDING;
-	window_update_file_list (window);
+	window_update_list_order (window);
 }
 
 
@@ -748,7 +895,7 @@ sort_list_reversed (GtkWidget *widget,
 		window->sort_type = GTK_SORT_DESCENDING;
 	else
 		window->sort_type = GTK_SORT_ASCENDING;
-	window_update_file_list (window);
+	window_update_list_order (window);
 }
 
 
@@ -760,3 +907,47 @@ stop_cb (GtkWidget *widget,
 	if (window->activity_ref > 0)
 		fr_process_stop (window->archive->process);
 }
+
+
+void
+reload_cb (GtkWidget *widget, 
+	   void *data)
+{
+	FRWindow *window = data;
+	if (window->activity_ref == 0)
+		window_archive_reload (window);
+}
+
+
+void
+test_cb (GtkWidget *widget, 
+	 void      *data)
+{
+	FRWindow *window = data;
+	fr_archive_test (window->archive, window->password);
+}
+
+
+void
+last_output_cb (GtkWidget *widget, 
+		void      *data)
+{
+	FRWindow *window = data;
+	window_view_last_output (window);
+}
+
+
+void
+view_toolbar_cb (GtkWidget *widget, 
+		 void      *data)
+{
+	eel_gconf_set_boolean (PREF_UI_TOOLBAR, GTK_CHECK_MENU_ITEM (widget)->active);
+}
+
+
+void
+view_statusbar_cb (GtkWidget *widget, 
+		   void      *data)
+{
+	eel_gconf_set_boolean (PREF_UI_STATUSBAR, GTK_CHECK_MENU_ITEM (widget)->active);
+}
