@@ -30,8 +30,8 @@
 
 typedef enum {
 	WINDOW_SORT_BY_NAME = 0,
-	WINDOW_SORT_BY_TYPE = 1,
-	WINDOW_SORT_BY_SIZE = 2,
+	WINDOW_SORT_BY_SIZE = 1,
+	WINDOW_SORT_BY_TYPE = 2,
 	WINDOW_SORT_BY_TIME = 3,
 	WINDOW_SORT_BY_PATH = 4
 } WindowSortMethod;
@@ -53,21 +53,28 @@ typedef enum {
 } FRCompressProgram;
 
 
+typedef enum {
+	FR_COMPRESSION_VERY_FAST,
+	FR_COMPRESSION_FAST,
+	FR_COMPRESSION_NORMAL,
+	FR_COMPRESSION_MAXIMUM,
+} FRCompression;
+
+
 typedef enum {
 	FR_PROC_ERROR_NONE,
 	FR_PROC_ERROR_GENERIC,
 	FR_PROC_ERROR_COMMAND_NOT_FOUND,
 	FR_PROC_ERROR_EXITED_ABNORMALLY,
-	FR_PROC_ERROR_PIPE,
-	FR_PROC_ERROR_FORK,
-	FR_PROC_ERROR_CANNOT_CHDIR,
+	FR_PROC_ERROR_SPAWN,
 	FR_PROC_ERROR_STOPPED
 } FRProcErrorType;
 
 
 typedef struct {
-	FRProcErrorType type;
-	int             status;
+	FRProcErrorType  type;
+	int              status;
+	GError          *gerror;
 } FRProcError;
 
 
